@@ -45,12 +45,6 @@
 #include <netinet/in_systm.h>
 #endif
 
-#if __cplusplus && HAVE_TR1_RANDOM
-#if !HAVE_STD_UNIFORM_INT_DISTRIBUTION && !HAVE_STD_UNIFORM_REAL_DISTRIBUTION
-#include <tr1/random>
-#endif
-#endif
-
 /******************************************************/
 /* Typedefs for missing entries on a system           */
 /******************************************************/
@@ -166,20 +160,5 @@ typedef long mtyp_t;
 #define NULL 0
 #endif
 
-/***********************************************************/
-/* uniform_int_distribution backward compatibility wrapper */
-/***********************************************************/
-#if HAVE_STD_UNIFORM_INT_DISTRIBUTION
-#define xuniform_int_distribution std::uniform_int_distribution
-#else
-#define xuniform_int_distribution std::tr1::uniform_int
-#endif
-
-#if HAVE_STD_UNIFORM_REAL_DISTRIBUTION
-#define xuniform_real_distribution std::uniform_real_distribution
-#else
-#define xuniform_real_distribution std::tr1::uniform_real
-#endif
-
 #endif /* SQUID_TYPES_H */
 
