@@ -36,6 +36,9 @@ class CollapsedForwardingMsg
 public:
     CollapsedForwardingMsg(): sender(-1), xitIndex(-1) {}
 
+    /// prints message parameters; suitable for cache manager reports
+    void stat(std::ostream &);
+
 public:
     int sender; ///< kid ID of sending process
 
@@ -43,6 +46,12 @@ public:
     sfileno xitIndex;
 };
 
+void
+CollapsedForwardingMsg::stat(std::ostream &os)
+{
+    os << "sender: " << sender << ", xitIndex: " << xitIndex;
+}
+
 // CollapsedForwarding
 
 void
@@ -152,17 +161,26 @@ CollapsedForwarding::HandleNewDataAtStart()
     HandleNewData("at start");
 }
 
+void
+CollapsedForwarding::StatQueue(std::ostream &os)
+{
+    if (queue.get()) {
+        os << "Transients queues:\n";
+        queue->stat<CollapsedForwardingMsg>(os);
+    }
+}
+
 /// initializes shared queue used by CollapsedForwarding
 class CollapsedForwardingRr: public Ipc::Mem::RegisteredRunner
 {
 public:
     /* RegisteredRunner API */
-    CollapsedForwardingRr(): owner(NULL) {}
-    virtual ~CollapsedForwardingRr();
+    CollapsedForwardingRr(): owner(nullptr) {}
+    ~CollapsedForwardingRr() override;
 
 protected:
-    virtual void create();
-    virtual void open();
+    void create() override;
+    void open() override;
 
 private:
     Ipc::MultiQueue::Owner *owner;
