@@ -16,13 +16,13 @@
 #include "DiskIO/DiskThreads/CommIO.h"
 #include "DiskThreads.h"
 #include "SquidConfig.h"
-#include "SquidTime.h"
 #include "Store.h"
 
 /*
  * struct stat and squidaio_xstrdup use explicit pool alloc()/freeOne().
  * XXX: convert to MEMPROXY_CLASS() API
  */
+#include "mem/Allocator.h"
 #include "mem/Pool.h"
 
 #include <cerrno>
@@ -103,7 +103,7 @@ static void *squidaio_do_opendir(squidaio_request_t *);
 static void squidaio_debug(squidaio_request_t *);
 static void squidaio_poll_queues(void);
 
-static squidaio_thread_t *threads = NULL;
+static squidaio_thread_t *threads = nullptr;
 static int squidaio_initialised = 0;
 
 #define AIO_LARGE_BUFS  16384
@@ -112,15 +112,15 @@ static int squidaio_initialised = 0;
 #define AIO_TINY_BUFS   AIO_LARGE_BUFS >> 3
 #define AIO_MICRO_BUFS  128
 
-static MemAllocator *squidaio_large_bufs = NULL;    /* 16K */
-static MemAllocator *squidaio_medium_bufs = NULL;   /* 8K */
-static MemAllocator *squidaio_small_bufs = NULL;    /* 4K */
-static MemAllocator *squidaio_tiny_bufs = NULL; /* 2K */
-static MemAllocator *squidaio_micro_bufs = NULL;    /* 128K */
+static Mem::Allocator *squidaio_large_bufs = nullptr; /* 16K */
+static Mem::Allocator *squidaio_medium_bufs = nullptr; /* 8K */
+static Mem::Allocator *squidaio_small_bufs = nullptr; /* 4K */
+static Mem::Allocator *squidaio_tiny_bufs = nullptr; /* 2K */
+static Mem::Allocator *squidaio_micro_bufs = nullptr; /* 128K */
 
 static int request_queue_len = 0;
-static MemAllocator *squidaio_request_pool = NULL;
-static MemAllocator *squidaio_thread_pool = NULL;
+static Mem::Allocator *squidaio_request_pool = nullptr;
+static Mem::Allocator *squidaio_thread_pool = nullptr;
 static squidaio_request_queue_t request_queue;
 
 static struct {
@@ -129,7 +129,7 @@ static struct {
 
 request_queue2 = {
 
-    NULL, &request_queue2.head
+    nullptr, &request_queue2.head
 };
 static squidaio_request_queue_t done_queue;
 
@@ -139,7 +139,7 @@ static struct {
 
 done_requests = {
 
-    NULL, &done_requests.head
+    nullptr, &done_requests.head
 };
 static pthread_attr_t globattr;
 #if HAVE_SCHED_H
@@ -148,7 +148,7 @@ static struct sched_param globsched;
 #endif
 static pthread_t main_thread;
 
-static MemAllocator *
+static Mem::Allocator *
 squidaio_get_pool(int size)
 {
     if (size <= AIO_LARGE_BUFS) {
@@ -164,16 +164,15 @@ squidaio_get_pool(int size)
             return squidaio_large_bufs;
     }
 
-    return NULL;
+    return nullptr;
 }
 
 void *
 squidaio_xmalloc(int size)
 {
     void *p;
-    MemAllocator *pool;
 
-    if ((pool = squidaio_get_pool(size)) != NULL) {
+    if (const auto pool = squidaio_get_pool(size)) {
         p = pool->alloc();
     } else
         p = xmalloc(size);
@@ -196,9 +195,7 @@ squidaio_xstrdup(const char *str)
 void
 squidaio_xfree(void *p, int size)
 {
-    MemAllocator *pool;
-
-    if ((pool = squidaio_get_pool(size)) != NULL) {
+    if (const auto pool = squidaio_get_pool(size)) {
         pool->freeOne(p);
     } else
         xfree(p);
@@ -207,10 +204,9 @@ squidaio_xfree(void *p, int size)
 static void
 squidaio_xstrfree(char *str)
 {
-    MemAllocator *pool;
     int len = strlen(str) + 1;
 
-    if ((pool = squidaio_get_pool(len)) != NULL) {
+    if (const auto pool = squidaio_get_pool(len)) {
         pool->freeOne(str);
     } else
         xfree(str);
@@ -260,13 +256,13 @@ squidaio_init(void)
     pthread_attr_setstacksize(&globattr, 256 * 1024);
 
     /* Initialize request queue */
-    if (pthread_mutex_init(&(request_queue.mutex), NULL))
+    if (pthread_mutex_init(&(request_queue.mutex), nullptr))
         fatal("Failed to create mutex");
 
-    if (pthread_cond_init(&(request_queue.cond), NULL))
+    if (pthread_cond_init(&(request_queue.cond), nullptr))
         fatal("Failed to create condition variable");
 
-    request_queue.head = NULL;
+    request_queue.head = nullptr;
 
     request_queue.tailp = &request_queue.head;
 
@@ -275,13 +271,13 @@ squidaio_init(void)
     request_queue.blocked = 0;
 
     /* Initialize done queue */
-    if (pthread_mutex_init(&(done_queue.mutex), NULL))
+    if (pthread_mutex_init(&(done_queue.mutex), nullptr))
         fatal("Failed to create mutex");
 
-    if (pthread_cond_init(&(done_queue.cond), NULL))
+    if (pthread_cond_init(&(done_queue.cond), nullptr))
         fatal("Failed to create condition variable");
 
-    done_queue.head = NULL;
+    done_queue.head = nullptr;
 
     done_queue.tailp = &done_queue.head;
 
@@ -301,7 +297,7 @@ squidaio_init(void)
     for (i = 0; i < NUMTHREADS; ++i) {
         threadp = (squidaio_thread_t *)squidaio_thread_pool->alloc();
         threadp->status = _THREAD_STARTING;
-        threadp->current_req = NULL;
+        threadp->current_req = nullptr;
         threadp->requests = 0;
         threadp->next = threads;
         threads = threadp;
@@ -375,11 +371,11 @@ squidaio_thread_loop(void *ptr)
     sigaddset(&newSig, SIGTERM);
     sigaddset(&newSig, SIGINT);
     sigaddset(&newSig, SIGALRM);
-    pthread_sigmask(SIG_BLOCK, &newSig, NULL);
+    pthread_sigmask(SIG_BLOCK, &newSig, nullptr);
 
     while (1) {
-        threadp->current_req = request = NULL;
-        request = NULL;
+        threadp->current_req = request = nullptr;
+        request = nullptr;
         /* Get a request to process */
         threadp->status = _THREAD_WAITING;
         pthread_mutex_lock(&request_queue.mutex);
@@ -401,7 +397,7 @@ squidaio_thread_loop(void *ptr)
         /* process the request */
         threadp->status = _THREAD_BUSY;
 
-        request->next = NULL;
+        request->next = nullptr;
 
         threadp->current_req = request;
 
@@ -461,7 +457,7 @@ squidaio_thread_loop(void *ptr)
         ++ threadp->requests;
     }               /* while forever */
 
-    return NULL;
+    return nullptr;
 }               /* squidaio_thread_loop */
 
 static void
@@ -476,7 +472,7 @@ squidaio_queue_request(squidaio_request_t * request)
     request_queue_len += 1;
     request->resultp->_data = request;
     /* Play some tricks with the request_queue2 queue */
-    request->next = NULL;
+    request->next = nullptr;
 
     if (pthread_mutex_trylock(&request_queue.mutex) == 0) {
         if (request_queue2.head) {
@@ -496,7 +492,7 @@ squidaio_queue_request(squidaio_request_t * request)
 
         if (request_queue2.head) {
             /* Clear queue of blocked requests */
-            request_queue2.head = NULL;
+            request_queue2.head = nullptr;
             request_queue2.tailp = &request_queue2.head;
         }
     } else {
@@ -512,7 +508,7 @@ squidaio_queue_request(squidaio_request_t * request)
         if (++filter >= filter_limit) {
             filter_limit += filter;
             filter = 0;
-            debugs(43, DBG_IMPORTANT, "squidaio_queue_request: WARNING - Queue congestion (growing to " << filter_limit << ")");
+            debugs(43, DBG_IMPORTANT, "WARNING: squidaio_queue_request: Queue congestion (growing to " << filter_limit << ")");
         }
     }
 
@@ -535,7 +531,7 @@ squidaio_queue_request(squidaio_request_t * request)
 
         if (squid_curtime >= (last_warn + 15) &&
                 squid_curtime >= (high_start + 5)) {
-            debugs(43, DBG_IMPORTANT, "squidaio_queue_request: WARNING - Disk I/O overloading");
+            debugs(43, DBG_IMPORTANT, "WARNING: squidaio_queue_request: Disk I/O overloading");
 
             if (squid_curtime >= (high_start + 15))
                 debugs(43, DBG_IMPORTANT, "squidaio_queue_request: Queue Length: current=" <<
@@ -613,7 +609,7 @@ squidaio_cleanup_request(squidaio_request_t * requestp)
         break;
     }
 
-    if (resultp != NULL && !cancelled) {
+    if (resultp != nullptr && !cancelled) {
         resultp->aio_return = requestp->ret;
         resultp->aio_errno = requestp->err;
     }
@@ -629,8 +625,8 @@ squidaio_cancel(squidaio_result_t * resultp)
     if (request && request->resultp == resultp) {
         debugs(43, 9, "squidaio_cancel: " << request << " type=" << request->request_type << " result=" << request->resultp);
         request->cancelled = 1;
-        request->resultp = NULL;
-        resultp->_data = NULL;
+        request->resultp = nullptr;
+        resultp->_data = nullptr;
         resultp->result_type = _AIO_OP_NONE;
         return 0;
     }
@@ -878,7 +874,7 @@ squidaio_poll_queues(void)
         request_queue.tailp = request_queue2.tailp;
         pthread_cond_signal(&request_queue.cond);
         pthread_mutex_unlock(&request_queue.mutex);
-        request_queue2.head = NULL;
+        request_queue2.head = nullptr;
         request_queue2.tailp = &request_queue2.head;
     }
 
@@ -886,7 +882,7 @@ squidaio_poll_queues(void)
     if (done_queue.head && pthread_mutex_trylock(&done_queue.mutex) == 0) {
 
         struct squidaio_request_t *requests = done_queue.head;
-        done_queue.head = NULL;
+        done_queue.head = nullptr;
         done_queue.tailp = &done_queue.head;
         pthread_mutex_unlock(&done_queue.mutex);
         *done_requests.tailp = requests;
@@ -912,7 +908,7 @@ squidaio_poll_done(void)
 AIO_REPOLL:
     request = done_requests.head;
 
-    if (request == NULL && !polled) {
+    if (request == nullptr && !polled) {
         CommIO::ResetNotifications();
         squidaio_poll_queues();
         polled = 1;
@@ -920,7 +916,7 @@ AIO_REPOLL:
     }
 
     if (!request) {
-        return NULL;
+        return nullptr;
     }
 
     debugs(43, 9, "squidaio_poll_done: " << request << " type=" << request->request_type << " result=" << request->resultp);
