@@ -29,7 +29,6 @@
 #include "ipc/UdsOp.h"
 #include "sbuf/SBuf.h"
 #include "SquidConfig.h"
-#include "SquidTime.h"
 #include "StatCounters.h"
 #include "tools.h"
 
@@ -65,13 +64,34 @@ struct SipcIo {
     int disker;
 };
 
-std::ostream &
+static std::ostream &
 operator <<(std::ostream &os, const SipcIo &sio)
 {
     return os << "ipcIo" << sio.worker << '.' << sio.msg.requestId <<
-           (sio.msg.command == IpcIo::cmdRead ? 'r' : 'w') << sio.disker;
+           sio.msg.command << sio.disker;
 }
 
+/* IpcIo::Command */
+
+std::ostream &
+IpcIo::operator <<(std::ostream &os, const Command command)
+{
+    switch (command) {
+    case cmdNone:
+        return os << '-';
+    case cmdOpen:
+        return os << 'o';
+    case cmdRead:
+        return os << 'r';
+    case cmdWrite:
+        return os << 'w';
+    }
+    // unreachable code
+    return os << static_cast<int>(command);
+}
+
+/* IpcIoFile */
+
 IpcIoFile::IpcIoFile(char const *aDb):
     dbName(aDb),
     myPid(getpid()),
@@ -185,7 +205,7 @@ IpcIoFile::create(int flags, mode_t mode, RefCount<IORequestor> callback)
 void
 IpcIoFile::close()
 {
-    assert(ioRequestor != NULL);
+    assert(ioRequestor != nullptr);
 
     if (IamDiskProcess())
         DiskerClose(SBuf(dbName.termedBuf()));
@@ -215,10 +235,10 @@ IpcIoFile::error() const
 void
 IpcIoFile::read(ReadRequest *readRequest)
 {
-    debugs(79,3, HERE << "(disker" << diskId << ", " << readRequest->len << ", " <<
+    debugs(79,3, "(disker" << diskId << ", " << readRequest->len << ", " <<
            readRequest->offset << ")");
 
-    assert(ioRequestor != NULL);
+    assert(ioRequestor != nullptr);
     assert(readRequest->offset >= 0);
     Must(!error_);
 
@@ -236,7 +256,7 @@ IpcIoFile::readCompleted(ReadRequest *readRequest,
 {
     bool ioError = false;
     if (!response) {
-        debugs(79, 3, HERE << "error: timeout");
+        debugs(79, 3, "error: timeout");
         ioError = true; // I/O timeout does not warrant setting error_?
     } else {
         if (response->xerrno) {
@@ -263,10 +283,10 @@ IpcIoFile::readCompleted(ReadRequest *readRequest,
 void
 IpcIoFile::write(WriteRequest *writeRequest)
 {
-    debugs(79,3, HERE << "(disker" << diskId << ", " << writeRequest->len << ", " <<
+    debugs(79,3, "(disker" << diskId << ", " << writeRequest->len << ", " <<
            writeRequest->offset << ")");
 
-    assert(ioRequestor != NULL);
+    assert(ioRequestor != nullptr);
     assert(writeRequest->len > 0); // TODO: work around mmap failures on zero-len?
     assert(writeRequest->offset >= 0);
     Must(!error_);
@@ -305,7 +325,7 @@ IpcIoFile::writeCompleted(WriteRequest *writeRequest,
         (writeRequest->free_func)(const_cast<char*>(writeRequest->buf)); // broken API?
 
     if (!ioError) {
-        debugs(79,5, HERE << "wrote " << writeRequest->len << " to disker" <<
+        debugs(79,5, "wrote " << writeRequest->len << " to disker" <<
                diskId << " at " << writeRequest->offset);
     }
 
@@ -341,7 +361,7 @@ IpcIoFile::push(IpcIoPendingRequest *const pending)
         HandleResponses("before push");
     });
 
-    debugs(47, 7, HERE);
+    debugs(47, 7, MYNAME);
     Must(diskId >= 0);
     Must(pending);
     Must(pending->readRequest || pending->writeRequest);
@@ -370,7 +390,7 @@ IpcIoFile::push(IpcIoPendingRequest *const pending)
             memcpy(buf, pending->writeRequest->buf, ipcIo.len); // optimize away
         }
 
-        debugs(47, 7, HERE << "pushing " << SipcIo(KidIdentifier, ipcIo, diskId));
+        debugs(47, 7, "pushing " << SipcIo(KidIdentifier, ipcIo, diskId));
 
         // protect DiskerHandleRequest() from pop queue overflow
         if (pendingRequests() >= QueueCapacity)
@@ -387,11 +407,11 @@ IpcIoFile::push(IpcIoPendingRequest *const pending)
         if (ipcIo.page)
             Ipc::Mem::PutPage(ipcIo.page);
 
-        pending->completeIo(NULL);
+        pending->completeIo(nullptr);
         delete pending;
     } catch (const TextException &e) {
         debugs(47, DBG_IMPORTANT, "ERROR: " << dbName << " exception: " << e.what());
-        pending->completeIo(NULL);
+        pending->completeIo(nullptr);
         delete pending;
     }
 }
@@ -424,9 +444,9 @@ IpcIoFile::canWait() const
     const int expectedWait = max(oldestWait, rateWait);
     if (expectedWait < 0 ||
             static_cast<time_msec_t>(expectedWait) < config.ioTimeout)
-        return true; // expected wait time is acceptible
+        return true; // expected wait time is acceptable
 
-    debugs(47,2, HERE << "cannot wait: " << expectedWait <<
+    debugs(47,2, "cannot wait: " << expectedWait <<
            " oldest: " << SipcIo(KidIdentifier, oldestIo, diskId));
     return false; // do not want to wait that long
 }
@@ -435,7 +455,7 @@ IpcIoFile::canWait() const
 void
 IpcIoFile::HandleOpenResponse(const Ipc::StrandMessage &response)
 {
-    debugs(47, 7, HERE << "coordinator response to open request");
+    debugs(47, 7, "coordinator response to open request");
     for (IpcIoFileList::iterator i = WaitingForOpen.begin();
             i != WaitingForOpen.end(); ++i) {
         if (response.strand.tag == (*i)->dbName) {
@@ -445,7 +465,7 @@ IpcIoFile::HandleOpenResponse(const Ipc::StrandMessage &response)
         }
     }
 
-    debugs(47, 4, HERE << "LATE disker response to open for " <<
+    debugs(47, 4, "LATE disker response to open for " <<
            response.strand.tag);
     // nothing we can do about it; completeIo() has been called already
 }
@@ -453,7 +473,7 @@ IpcIoFile::HandleOpenResponse(const Ipc::StrandMessage &response)
 void
 IpcIoFile::HandleResponses(const char *const when)
 {
-    debugs(47, 4, HERE << "popping all " << when);
+    debugs(47, 4, "popping all " << when);
     IpcIoMsg ipcIo;
     // get all responses we can: since we are not pushing, this will stop
     int diskId;
@@ -492,7 +512,7 @@ void
 IpcIoFile::Notify(const int peerId)
 {
     // TODO: Count and report the total number of notifications, pops, pushes.
-    debugs(47, 7, HERE << "kid" << peerId);
+    debugs(47, 7, "kid" << peerId);
     Ipc::TypedMsgHdr msg;
     msg.setType(Ipc::mtIpcIoNotification); // TODO: add proper message type?
     msg.putInt(KidIdentifier);
@@ -504,7 +524,7 @@ void
 IpcIoFile::HandleNotification(const Ipc::TypedMsgHdr &msg)
 {
     const int from = msg.getInt();
-    debugs(47, 7, HERE << "from " << from);
+    debugs(47, 7, "from " << from);
     queue->clearReaderSignal(from);
     if (IamDiskProcess())
         DiskerHandleRequests();
@@ -524,6 +544,15 @@ IpcIoFile::HandleMessagesAtStart()
         HandleResponses("at start");
 }
 
+void
+IpcIoFile::StatQueue(std::ostream &os)
+{
+    if (queue.get()) {
+        os << "SMP disk I/O queues:\n";
+        queue->stat<IpcIoMsg>(os);
+    }
+}
+
 /// handles open request timeout
 void
 IpcIoFile::OpenTimeout(void *const param)
@@ -535,7 +564,7 @@ IpcIoFile::OpenTimeout(void *const param)
     for (IpcIoFileList::iterator i = WaitingForOpen.begin();
             i != WaitingForOpen.end(); ++i) {
         if (*i == ipcIoFile) {
-            (*i)->openCompleted(NULL);
+            (*i)->openCompleted(nullptr);
             WaitingForOpen.erase(i);
             break;
         }
@@ -548,7 +577,7 @@ IpcIoFile::CheckTimeouts(void *const param)
 {
     Must(param);
     const int diskId = reinterpret_cast<uintptr_t>(param);
-    debugs(47, 7, HERE << "diskId=" << diskId);
+    debugs(47, 7, "diskId=" << diskId);
     const IpcIoFilesMap::const_iterator i = IpcIoFiles.find(diskId);
     if (i != IpcIoFiles.end())
         i->second->checkTimeouts();
@@ -616,7 +645,7 @@ IpcIoFile::dequeueRequest(const unsigned int requestId)
 {
     Must(requestId != 0);
 
-    RequestMap *map = NULL;
+    RequestMap *map = nullptr;
     RequestMap::iterator i = requestMap1.find(requestId);
 
     if (i != requestMap1.end())
@@ -628,7 +657,7 @@ IpcIoFile::dequeueRequest(const unsigned int requestId)
     }
 
     if (!map) // not found in both maps
-        return NULL;
+        return nullptr;
 
     IpcIoPendingRequest *pending = i->second;
     map->erase(i);
@@ -656,6 +685,22 @@ IpcIoMsg::IpcIoMsg():
     start.tv_usec = 0;
 }
 
+void
+IpcIoMsg::stat(std::ostream &os)
+{
+    timeval elapsedTime;
+    tvSub(elapsedTime, start, current_time);
+    os << "id: " << requestId <<
+       ", offset: " << offset <<
+       ", size: " << len <<
+       ", workerPid: " << workerPid <<
+       ", page: " << page <<
+       ", command: " << command <<
+       ", start: " << start <<
+       ", elapsed: " << elapsedTime <<
+       ", errno: " << xerrno;
+}
+
 /* IpcIoPendingRequest */
 
 IpcIoPendingRequest::IpcIoPendingRequest(const IpcIoFile::Pointer &aFile):
@@ -675,7 +720,7 @@ IpcIoPendingRequest::completeIo(IpcIoMsg *const response)
         file->writeCompleted(writeRequest, response);
     else {
         Must(!response); // only timeouts are handled here
-        file->openCompleted(NULL);
+        file->openCompleted(nullptr);
     }
 }
 
@@ -689,7 +734,7 @@ diskerRead(IpcIoMsg &ipcIo)
 {
     if (!Ipc::Mem::GetPage(Ipc::Mem::PageId::ioPage, ipcIo.page)) {
         ipcIo.len = 0;
-        debugs(47,2, HERE << "run out of shared memory pages for IPC I/O");
+        debugs(47,2, "run out of shared memory pages for IPC I/O");
         return;
     }
 
@@ -701,13 +746,13 @@ diskerRead(IpcIoMsg &ipcIo)
     if (read >= 0) {
         ipcIo.xerrno = 0;
         const size_t len = static_cast<size_t>(read); // safe because read > 0
-        debugs(47,8, HERE << "disker" << KidIdentifier << " read " <<
+        debugs(47,8, "disker" << KidIdentifier << " read " <<
                (len == ipcIo.len ? "all " : "just ") << read);
         ipcIo.len = len;
     } else {
         ipcIo.xerrno = errno;
         ipcIo.len = 0;
-        debugs(47,5, HERE << "disker" << KidIdentifier << " read error: " <<
+        debugs(47,5, "disker" << KidIdentifier << " read error: " <<
                ipcIo.xerrno);
     }
 }
@@ -780,7 +825,7 @@ diskerWrite(IpcIoMsg &ipcIo)
 void
 IpcIoFile::DiskerHandleMoreRequests(void *source)
 {
-    debugs(47, 7, HERE << "resuming handling requests after " <<
+    debugs(47, 7, "resuming handling requests after " <<
            static_cast<const char *>(source));
     DiskerHandleMoreRequestsScheduled = false;
     IpcIoFile::DiskerHandleRequests();
@@ -818,7 +863,7 @@ IpcIoFile::WaitBeforePop()
     Ipc::QueueReader::Balance &balance = queue->localBalance();
     balance += static_cast<int64_t>(credit - debit);
 
-    debugs(47, 7, HERE << "rate limiting balance: " << balance << " after +" << credit << " -" << debit);
+    debugs(47, 7, "rate limiting balance: " << balance << " after +" << credit << " -" << debit);
 
     if (ipcIo.command == IpcIo::cmdWrite && balance > maxImbalance) {
         // if the next request is (likely) write and we accumulated
@@ -831,7 +876,7 @@ IpcIoFile::WaitBeforePop()
                    "I/O requests for " << (toSpend/1e3) << " seconds " <<
                    "to obey " << ioRate << "/sec rate limit");
 
-        debugs(47, 3, HERE << "rate limiting by " << toSpend << " ms to get" <<
+        debugs(47, 3, "rate limiting by " << toSpend << " ms to get" <<
                (1e3*maxRate) << "/sec rate");
         eventAdd("IpcIoFile::DiskerHandleMoreRequests",
                  &IpcIoFile::DiskerHandleMoreRequests,
@@ -877,7 +922,7 @@ IpcIoFile::DiskerHandleRequests()
                          minBreakSecs, 0, false);
                 DiskerHandleMoreRequestsScheduled = true;
             }
-            debugs(47, 3, HERE << "pausing after " << popped << " I/Os in " <<
+            debugs(47, 3, "pausing after " << popped << " I/Os in " <<
                    elapsedMsec << "ms; " << (elapsedMsec/popped) << "ms per I/O");
             break;
         }
@@ -900,7 +945,7 @@ IpcIoFile::DiskerHandleRequest(const int workerId, IpcIoMsg &ipcIo)
         return;
     }
 
-    debugs(47,5, HERE << "disker" << KidIdentifier <<
+    debugs(47,5, "disker" << KidIdentifier <<
            (ipcIo.command == IpcIo::cmdRead ? " reads " : " writes ") <<
            ipcIo.len << " at " << ipcIo.offset <<
            " ipcIo" << workerId << '.' << ipcIo.requestId);
@@ -915,7 +960,7 @@ IpcIoFile::DiskerHandleRequest(const int workerId, IpcIoMsg &ipcIo)
 
     assert(ipcIo.workerPid == workerPid);
 
-    debugs(47, 7, HERE << "pushing " << SipcIo(workerId, ipcIo, KidIdentifier));
+    debugs(47, 7, "pushing " << SipcIo(workerId, ipcIo, KidIdentifier));
 
     try {
         if (queue->push(workerId, ipcIo))
@@ -923,7 +968,7 @@ IpcIoFile::DiskerHandleRequest(const int workerId, IpcIoMsg &ipcIo)
     } catch (const Queue::Full &) {
         // The worker pop queue should not overflow because the worker can
         // push only if pendingRequests() is less than QueueCapacity.
-        debugs(47, DBG_IMPORTANT, "BUG: Worker I/O pop queue for " <<
+        debugs(47, DBG_IMPORTANT, "ERROR: Squid BUG: Worker I/O pop queue for " <<
                DbName << " overflow: " <<
                SipcIo(workerId, ipcIo, KidIdentifier)); // TODO: report queue len
 
@@ -956,7 +1001,7 @@ DiskerClose(const SBuf &path)
 {
     if (TheFile >= 0) {
         file_close(TheFile);
-        debugs(79,3, HERE << "rock db closed " << path << ": FD " << TheFile);
+        debugs(79,3, "rock db closed " << path << ": FD " << TheFile);
         TheFile = -1;
         --store_open_disk_fd;
     }
@@ -969,13 +1014,13 @@ class IpcIoRr: public Ipc::Mem::RegisteredRunner
 {
 public:
     /* RegisteredRunner API */
-    IpcIoRr(): owner(NULL) {}
-    virtual ~IpcIoRr();
-    virtual void claimMemoryNeeds();
+    IpcIoRr(): owner(nullptr) {}
+    ~IpcIoRr() override;
+    void claimMemoryNeeds() override;
 
 protected:
     /* Ipc::Mem::RegisteredRunner API */
-    virtual void create();
+    void create() override;
 
 private:
     Ipc::FewToFewBiQueue::Owner *owner;
