@@ -9,7 +9,7 @@
 /* DEBUG: section 47    Store Directory Routines */
 
 #include "squid.h"
-#include "Debug.h"
+#include "debug/Stream.h"
 #include "DiskIO/IORequestor.h"
 #include "DiskIO/Mmapped/MmappedFile.h"
 #include "DiskIO/ReadRequest.h"
@@ -58,7 +58,7 @@ MmappedFile::MmappedFile(char const *aPath): fd(-1),
 {
     assert(aPath);
     path_ = xstrdup(aPath);
-    debugs(79,5, HERE << this << ' ' << path_);
+    debugs(79,5, this << ' ' << path_);
 }
 
 MmappedFile::~MmappedFile()
@@ -117,9 +117,9 @@ void MmappedFile::doClose()
 void
 MmappedFile::close()
 {
-    debugs(79, 3, HERE << this << " closing for " << ioRequestor);
+    debugs(79, 3, this << " closing for " << ioRequestor);
     doClose();
-    assert(ioRequestor != NULL);
+    assert(ioRequestor != nullptr);
     ioRequestor->closeCompleted();
 }
 
@@ -144,11 +144,11 @@ MmappedFile::error() const
 void
 MmappedFile::read(ReadRequest *aRequest)
 {
-    debugs(79,3, HERE << "(FD " << fd << ", " << aRequest->len << ", " <<
+    debugs(79,3, "(FD " << fd << ", " << aRequest->len << ", " <<
            aRequest->offset << ")");
 
     assert(fd >= 0);
-    assert(ioRequestor != NULL);
+    assert(ioRequestor != nullptr);
     assert(aRequest->len > 0); // TODO: work around mmap failures on zero-len?
     assert(aRequest->offset >= 0);
     assert(!error_); // TODO: propagate instead?
@@ -174,11 +174,11 @@ MmappedFile::read(ReadRequest *aRequest)
 void
 MmappedFile::write(WriteRequest *aRequest)
 {
-    debugs(79,3, HERE << "(FD " << fd << ", " << aRequest->len << ", " <<
+    debugs(79,3, "(FD " << fd << ", " << aRequest->len << ", " <<
            aRequest->offset << ")");
 
     assert(fd >= 0);
-    assert(ioRequestor != NULL);
+    assert(ioRequestor != nullptr);
     assert(aRequest->len > 0); // TODO: work around mmap failures on zero-len?
     assert(aRequest->offset >= 0);
     assert(!error_); // TODO: propagate instead?
@@ -189,10 +189,10 @@ MmappedFile::write(WriteRequest *aRequest)
     const ssize_t written =
         pwrite(fd, aRequest->buf, aRequest->len, aRequest->offset);
     if (written < 0) {
-        debugs(79, DBG_IMPORTANT, HERE << "error: " << xstrerr(errno));
+        debugs(79, DBG_IMPORTANT, "ERROR: " << xstrerr(errno));
         error_ = true;
     } else if (static_cast<size_t>(written) != aRequest->len) {
-        debugs(79, DBG_IMPORTANT, HERE << "problem: " << written << " < " << aRequest->len);
+        debugs(79, DBG_IMPORTANT, "problem: " << written << " < " << aRequest->len);
         error_ = true;
     }
 
@@ -200,7 +200,7 @@ MmappedFile::write(WriteRequest *aRequest)
         (aRequest->free_func)(const_cast<char*>(aRequest->buf)); // broken API?
 
     if (!error_) {
-        debugs(79,5, HERE << "wrote " << aRequest->len << " to FD " << fd << " at " << aRequest->offset);
+        debugs(79,5, "wrote " << aRequest->len << " to FD " << fd << " at " << aRequest->offset);
     } else {
         doClose();
     }
@@ -219,7 +219,7 @@ MmappedFile::ioInProgress() const
 
 Mmapping::Mmapping(int aFd, size_t aLength, int aProt, int aFlags, off_t anOffset):
     fd(aFd), length(aLength), prot(aProt), flags(aFlags), offset(anOffset),
-    delta(-1), buf(NULL)
+    delta(-1), buf(nullptr)
 {
 }
 
@@ -236,14 +236,14 @@ Mmapping::map()
     static const int pageSize = getpagesize();
     delta = offset % pageSize;
 
-    buf = mmap(NULL, length + delta, prot, flags, fd, offset - delta);
+    buf = mmap(nullptr, length + delta, prot, flags, fd, offset - delta);
 
     if (buf == MAP_FAILED) {
         const int errNo = errno;
-        debugs(79,3, HERE << "error FD " << fd << "mmap(" << length << '+' <<
+        debugs(79,3, "error FD " << fd << "mmap(" << length << '+' <<
                delta << ", " << offset << '-' << delta << "): " << xstrerr(errNo));
-        buf = NULL;
-        return NULL;
+        buf = nullptr;
+        return nullptr;
     }
 
     return static_cast<char*>(buf) + delta;
@@ -252,7 +252,7 @@ Mmapping::map()
 bool
 Mmapping::unmap()
 {
-    debugs(79,9, HERE << "FD " << fd <<
+    debugs(79,9, "FD " << fd <<
            " munmap(" << buf << ", " << length << '+' << delta << ')');
 
     if (!buf) // forgot or failed to map
@@ -261,11 +261,11 @@ Mmapping::unmap()
     const bool error = munmap(buf, length + delta) != 0;
     if (error) {
         const int errNo = errno;
-        debugs(79,3, HERE << "error FD " << fd <<
+        debugs(79,3, "error FD " << fd <<
                " munmap(" << buf << ", " << length << '+' << delta << "): " <<
                "): " << xstrerr(errNo));
     }
-    buf = NULL;
+    buf = nullptr;
     return !error;
 }
 
