@@ -8,6 +8,7 @@
 
 #include "squid.h"
 #include "AccessLogEntry.h"
+#include "base/AsyncCallbacks.h"
 #include "base/CodeContext.h"
 #include "CachePeer.h"
 #include "errorpage.h"
@@ -100,11 +101,11 @@ public:
     PrimeChanceGiver(): HappyOrderEnforcer("happy_eyeballs_connect_timeout enforcement") {}
 
     /* HappyOrderEnforcer API */
-    virtual bool readyNow(const HappyConnOpener &job) const override;
+    bool readyNow(const HappyConnOpener &job) const override;
 
 private:
     /* HappyOrderEnforcer API */
-    virtual AsyncCall::Pointer notify(const CbcPointer<HappyConnOpener> &) override;
+    AsyncCall::Pointer notify(const CbcPointer<HappyConnOpener> &) override;
 };
 
 /// enforces happy_eyeballs_connect_gap and happy_eyeballs_connect_limit
@@ -114,7 +115,7 @@ public:
     SpareAllowanceGiver(): HappyOrderEnforcer("happy_eyeballs_connect_gap/happy_eyeballs_connect_limit enforcement") {}
 
     /* HappyOrderEnforcer API */
-    virtual bool readyNow(const HappyConnOpener &job) const override;
+    bool readyNow(const HappyConnOpener &job) const override;
 
     /// reacts to HappyConnOpener discovering readyNow() conditions for a spare path
     /// the caller must attempt to open a spare connection immediately
@@ -128,7 +129,7 @@ public:
 
 private:
     /* HappyOrderEnforcer API */
-    virtual AsyncCall::Pointer notify(const CbcPointer<HappyConnOpener> &) override;
+    AsyncCall::Pointer notify(const CbcPointer<HappyConnOpener> &) override;
 
     bool concurrencyLimitReached() const;
     void recordAllowance();
@@ -326,10 +327,10 @@ HappyConnOpenerAnswer::~HappyConnOpenerAnswer()
 
 /* HappyConnOpener */
 
-HappyConnOpener::HappyConnOpener(const ResolvedPeers::Pointer &dests, const AsyncCall::Pointer &aCall, HttpRequest::Pointer &request, const time_t aFwdStart, int tries, const AccessLogEntry::Pointer &anAle):
+HappyConnOpener::HappyConnOpener(const ResolvedPeers::Pointer &dests, const AsyncCallback<Answer> &callback, const HttpRequest::Pointer &request, const time_t aFwdStart, const int tries, const AccessLogEntry::Pointer &anAle):
     AsyncJob("HappyConnOpener"),
     fwdStart(aFwdStart),
-    callback_(aCall),
+    callback_(callback),
     destinations(dests),
     prime(&HappyConnOpener::notePrimeConnectDone, "HappyConnOpener::notePrimeConnectDone"),
     spare(&HappyConnOpener::noteSpareConnectDone, "HappyConnOpener::noteSpareConnectDone"),
@@ -338,7 +339,6 @@ HappyConnOpener::HappyConnOpener(const ResolvedPeers::Pointer &dests, const Asyn
     n_tries(tries)
 {
     assert(destinations);
-    assert(dynamic_cast<Answer*>(callback_->getDialer()));
 }
 
 HappyConnOpener::~HappyConnOpener()
@@ -446,17 +446,32 @@ HappyConnOpener::status() const
         os << "spare:" << spare;
     if (n_tries)
         os << " tries:" << n_tries;
+    os << " dst:" << *destinations;
     os << ' ' << id << ']';
 
     buf = os.buf();
     return buf.c_str();
 }
 
-/// Create "503 Service Unavailable" or "504 Gateway Timeout" error depending
-/// on whether this is a validation request. RFC 7234 section 5.2.2 says that
-/// we MUST reply with "504 Gateway Timeout" if validation fails and cached
-/// reply has proxy-revalidate, must-revalidate or s-maxage Cache-Control
-/// directive.
+/**
+ * Create "503 Service Unavailable" or "504 Gateway Timeout" error depending
+ * on whether this is a validation request.
+ *
+ * RFC 9111 section 5.2.2 Cache-Control response directives
+ *
+ * section 5.2.2.2 must-revalidate
+ * " if a cache is disconnected, the cache MUST generate an error response
+ *   rather than reuse the stale response.  The generated status code
+ *   SHOULD be 504 (Gateway Timeout) unless another error status code is
+ *   more applicable."
+ *
+ * section 5.2.2.8 proxy-revalidate
+ * " analogous to must-revalidate "
+ *
+ * section 5.2.2.10 s-maxage
+ * " incorporates the semantics of the
+ *   proxy-revalidate response directive "
+ */
 ErrorState *
 HappyConnOpener::makeError(const err_type type) const
 {
@@ -470,12 +485,12 @@ HappyConnOpener::Answer *
 HappyConnOpener::futureAnswer(const PeerConnectionPointer &conn)
 {
     if (callback_ && !callback_->canceled()) {
-        const auto answer = dynamic_cast<Answer *>(callback_->getDialer());
-        assert(answer);
-        answer->conn = conn;
-        answer->n_tries = n_tries;
-        return answer;
+        auto &answer = callback_.answer();
+        answer.conn = conn;
+        answer.n_tries = n_tries;
+        return &answer;
     }
+    (void)callback_.release();
     return nullptr;
 }
 
@@ -487,9 +502,8 @@ HappyConnOpener::sendSuccess(const PeerConnectionPointer &conn, const bool reuse
     if (auto *answer = futureAnswer(conn)) {
         answer->reused = reused;
         assert(!answer->error);
-        ScheduleCallHere(callback_);
+        ScheduleCallHere(callback_.release());
     }
-    callback_ = nullptr;
 }
 
 /// cancels the in-progress attempt, making its path a future candidate
@@ -512,9 +526,8 @@ HappyConnOpener::sendFailure()
         answer->error = lastError;
         assert(answer->error.valid());
         lastError = nullptr; // the answer owns it now
-        ScheduleCallHere(callback_);
+        ScheduleCallHere(callback_.release());
     }
-    callback_ = nullptr;
 }
 
 void
@@ -617,8 +630,6 @@ HappyConnOpener::handleConnOpenerAnswer(Attempt &attempt, const CommConnectCbPar
     }
 
     debugs(17, 8, what << " failed: " << params.conn);
-    if (const auto peer = params.conn->getPeer())
-        peerConnectFailed(peer);
 
     // remember the last failure (we forward it if we cannot connect anywhere)
     lastFailedConnection = handledPath;
@@ -627,6 +638,8 @@ HappyConnOpener::handleConnOpenerAnswer(Attempt &attempt, const CommConnectCbPar
     lastError = makeError(ERR_CONNECT_FAIL);
     lastError->xerrno = params.xerrno;
 
+    NoteOutgoingConnectionFailure(params.conn->getPeer(), lastError->httpStatus);
+
     if (spareWaiting)
         updateSpareWaitAfterPrimeFailure();
 
@@ -690,14 +703,13 @@ HappyConnOpener::cancelSpareWait(const char *reason)
 
 /** Called when an external event changes initiator interest, destinations,
  * prime, spare, or spareWaiting. Leaves HappyConnOpener in one of these
- * (mutually exclusive beyond the exceptional state #0) "stable" states:
+ * mutually exclusive "stable" states:
  *
- * 0. Exceptional termination: done()
- * 1. Processing a single peer: currentPeer
+ * 1. Processing a single peer: currentPeer && !done()
  *    1.1. Connecting: prime || spare
  *    1.2. Waiting for spare gap and/or paths: !prime && !spare
- * 2. Waiting for a new peer: destinations->empty() && !destinations->destinationsFinalized && !currentPeer
- * 3. Finished: destinations->empty() && destinations->destinationsFinalized && !currentPeer
+ * 2. Waiting for a new peer: destinations->empty() && !destinations->destinationsFinalized && !currentPeer && !done()
+ * 3. Terminating: done()
  */
 void
 HappyConnOpener::checkForNewConnection()
@@ -730,43 +742,13 @@ HappyConnOpener::checkForNewConnection()
         spareWaiting.forNewPeer = true;
     }
 
-    // open a new prime and/or a new spare connection if needed
-    if (!destinations->empty()) {
-        if (!currentPeer) {
-            auto newPrime = destinations->extractFront();
-            currentPeer = newPrime;
-            Must(currentPeer);
-            debugs(17, 7, "new peer " << *currentPeer);
-            primeStart = current_dtime;
-            startConnecting(prime, newPrime);
-            // TODO: if reuseOldConnection() in startConnecting() above succeeds,
-            // then we should not get here, and Must(prime) below will fail.
-            maybeGivePrimeItsChance();
-            Must(prime); // entering state #1.1
-        } else {
-            if (!prime)
-                maybeOpenAnotherPrimeConnection(); // may make destinations empty()
-        }
+    if (!prime)
+        maybeOpenPrimeConnection();
 
-        if (!spare && !spareWaiting)
-            maybeOpenSpareConnection(); // may make destinations empty()
+    if (!spare && !done())
+        maybeOpenSpareConnection();
 
-        Must(currentPeer);
-    }
-
-    if (currentPeer) {
-        debugs(17, 7, "working on " << *currentPeer);
-        return; // remaining in state #1.1 or #1.2
-    }
-
-    if (!destinations->destinationsFinalized) {
-        debugs(17, 7, "waiting for more peers");
-        return; // remaining in state #2
-    }
-
-    debugs(17, 7, "done; no more peers");
-    Must(doneAll());
-    // entering state #3
+    // any state is possible at this point
 }
 
 void
@@ -797,9 +779,30 @@ HappyConnOpener::noteSpareAllowance()
 
 /// starts a prime connection attempt if possible or does nothing otherwise
 void
-HappyConnOpener::maybeOpenAnotherPrimeConnection()
+HappyConnOpener::maybeOpenPrimeConnection()
 {
-    Must(currentPeer);
+    Must(!prime);
+
+    if (destinations->empty())
+        return;
+
+    if (!currentPeer) {
+        auto newPrime = destinations->extractFront();
+        currentPeer = newPrime;
+        Must(currentPeer);
+        debugs(17, 7, "new peer " << *currentPeer);
+        primeStart = current_dtime;
+        startConnecting(prime, newPrime);
+        if (done()) // probably reused a pconn
+            return;
+
+        Must(prime);
+        maybeGivePrimeItsChance();
+        return;
+    }
+
+    // currentPeer implies there is a spare attempt; meanwhile, the previous
+    // primary attempt has failed; do another attempt on the primary track
     if (auto dest = destinations->extractPrime(*currentPeer))
         startConnecting(prime, dest);
     // else wait for more prime paths or their exhaustion
@@ -843,11 +846,16 @@ HappyConnOpener::maybeOpenSpareConnection()
 {
     Must(currentPeer);
     Must(!spare);
-    Must(!spareWaiting);
     Must(!gotSpareAllowance);
 
+    if (spareWaiting)
+        return; // too early
+
     if (ranOutOfTimeOrAttempts())
-        return; // will quit or continue working on prime
+        return; // too late
+
+    if (destinations->empty())
+        return;
 
     // jobGotInstantAllowance() call conditions below rely on the readyNow() check here
     if (!ignoreSpareRestrictions && // we have to honor spare restrictions
