@@ -16,7 +16,7 @@ class StoreIOBuffer
 {
 
 public:
-    StoreIOBuffer():length(0), offset (0), data (NULL) {flags.error = 0;}
+    StoreIOBuffer():length(0), offset (0), data (nullptr) {flags.error = 0;}
 
     StoreIOBuffer(size_t aLength, int64_t anOffset, char *someData) :
         length (aLength), offset (anOffset), data (someData) {
