@@ -10,8 +10,9 @@
 #include "acl/AllOf.h"
 #include "acl/BoolOps.h"
 #include "acl/Checklist.h"
-#include "globals.h"
+#include "cache_cf.h"
 #include "MemBuf.h"
+#include "sbuf/SBuf.h"
 
 char const *
 Acl::AllOf::typeString() const
@@ -19,12 +20,6 @@ Acl::AllOf::typeString() const
     return "all-of";
 }
 
-ACL *
-Acl::AllOf::clone() const
-{
-    return new AllOf;
-}
-
 SBufList
 Acl::AllOf::dump() const
 {
@@ -50,8 +45,8 @@ Acl::AllOf::doMatch(ACLChecklist *checklist, Nodes::const_iterator start) const
 void
 Acl::AllOf::parse()
 {
-    Acl::InnerNode *whole = NULL;
-    ACL *oldNode = empty() ? NULL : nodes.front();
+    Acl::InnerNode *whole = nullptr;
+    ACL *oldNode = empty() ? nullptr : nodes.front();
 
     // optimization: this logic reduces subtree hight (number of tree levels)
     if (Acl::OrNode *oldWhole = dynamic_cast<Acl::OrNode*>(oldNode)) {
