@@ -9,13 +9,13 @@
 #ifndef SQUID_ADAPTATION__ACCESS_CHECK_H
 #define SQUID_ADAPTATION__ACCESS_CHECK_H
 
-#include "AccessLogEntry.h"
 #include "acl/Acl.h"
 #include "adaptation/Elements.h"
 #include "adaptation/forward.h"
 #include "adaptation/Initiator.h"
 #include "adaptation/ServiceFilter.h"
 #include "base/AsyncJob.h"
+#include "log/forward.h"
 
 class HttpRequest;
 class HttpReply;
@@ -29,19 +29,19 @@ class AccessRule;
 // checks adaptation_access rules to find a matching adaptation service
 class AccessCheck: public virtual AsyncJob
 {
-    CBDATA_CLASS(AccessCheck);
+    CBDATA_CHILD(AccessCheck);
 
 public:
     typedef void AccessCheckCallback(ServiceGroupPointer group, void *data);
 
     // use this to start async ACL checks; returns true if started
     static bool Start(Method method, VectPoint vp, HttpRequest *req,
-                      HttpReply *rep, AccessLogEntry::Pointer &al, Adaptation::Initiator *initiator);
+                      HttpReply *, const AccessLogEntryPointer &, Adaptation::Initiator *);
 
 protected:
     // use Start to start adaptation checks
     AccessCheck(const ServiceFilter &aFilter, Adaptation::Initiator *);
-    ~AccessCheck();
+    ~AccessCheck() override;
 
 private:
     const ServiceFilter filter;
@@ -64,8 +64,8 @@ public:
 
 protected:
     // AsyncJob API
-    virtual void start();
-    virtual bool doneAll() const { return false; } /// not done until mustStop
+    void start() override;
+    bool doneAll() const override { return false; } /// not done until mustStop
 
     bool usedDynamicRules();
     void check();
