@@ -10,6 +10,7 @@
 
 #include "squid.h"
 #include "anyp/Uri.h"
+#include "base/Raw.h"
 #include "globals.h"
 #include "HttpRequest.h"
 #include "parser/Tokenizer.h"
@@ -70,7 +71,7 @@ AnyP::Uri::Encode(const SBuf &buf, const CharacterSet &ignore)
     while (!tk.atEnd()) {
         // TODO: Add Tokenizer::parseOne(void).
         const auto ch = tk.remaining()[0];
-        output.appendf("%%%02X", static_cast<unsigned int>(static_cast<unsigned char>(ch))); // TODO: Optimize using a table
+        output.appendf("%%%02X", static_cast<unsigned int>(ch)); // TODO: Optimize using a table
         (void)tk.skip(ch);
 
         if (tk.prefix(goodSection, ignore))
@@ -173,10 +174,6 @@ urlInitialize(void)
     assert(0 == matchDomainName("*.foo.com", ".foo.com", mdnHonorWildcards));
     assert(0 != matchDomainName("*.foo.com", "foo.com", mdnHonorWildcards));
 
-    assert(0 != matchDomainName("foo.com", ""));
-    assert(0 != matchDomainName("foo.com", "", mdnHonorWildcards));
-    assert(0 != matchDomainName("foo.com", "", mdnRejectSubsubDomains));
-
     /* more cases? */
 }
 
@@ -261,8 +258,8 @@ AnyP::Uri::parse(const HttpRequestMethod& method, const SBuf &rawUrl)
         LOCAL_ARRAY(char, login, MAX_URL);
         LOCAL_ARRAY(char, foundHost, MAX_URL);
         LOCAL_ARRAY(char, urlpath, MAX_URL);
-        char *t = NULL;
-        char *q = NULL;
+        char *t = nullptr;
+        char *q = nullptr;
         int foundPort;
         int l;
         int i;
@@ -330,7 +327,7 @@ AnyP::Uri::parse(const HttpRequestMethod& method, const SBuf &rawUrl)
             src = url;
             i = 0;
 
-            /* Then everything until first /; thats host (and port; which we'll look for here later) */
+            /* Then everything until first /; that's host (and port; which we'll look for here later) */
             // bug 1881: If we don't get a "/" then we imply it was there
             // bug 3074: We could just be given a "?" or "#". These also imply "/"
             // bug 3233: whitespace is also a hostname delimiter.
@@ -355,7 +352,7 @@ AnyP::Uri::parse(const HttpRequestMethod& method, const SBuf &rawUrl)
             } else {
                 dst = urlpath;
             }
-            /* Then everything from / (inclusive) until \r\n or \0 - thats urlpath */
+            /* Then everything from / (inclusive) until \r\n or \0 - that's urlpath */
             for (; i < l && *src != '\r' && *src != '\n' && *src != '\0'; ++i, ++src, ++dst) {
                 *dst = *src;
             }
@@ -369,7 +366,7 @@ AnyP::Uri::parse(const HttpRequestMethod& method, const SBuf &rawUrl)
 
             /* Is there any login information? (we should eventually parse it above) */
             t = strrchr(foundHost, '@');
-            if (t != NULL) {
+            if (t != nullptr) {
                 strncpy((char *) login, (char *) foundHost, sizeof(login)-1);
                 login[sizeof(login)-1] = '\0';
                 t = strrchr(login, '@');
@@ -408,7 +405,7 @@ AnyP::Uri::parse(const HttpRequestMethod& method, const SBuf &rawUrl)
                     /* RFC 2732 states IPv6 "SHOULD" be bracketed. allowing for times when its not. */
                     /* RFC 3986 'update' simply modifies this to an "is" with no emphasis at all! */
                     /* therefore we MUST accept the case where they are not bracketed at all. */
-                    t = NULL;
+                    t = nullptr;
                 }
             }
 
@@ -468,15 +465,6 @@ AnyP::Uri::parse(const HttpRequestMethod& method, const SBuf &rawUrl)
             return false;
         }
 
-#if HARDCODE_DENY_PORTS
-        /* These ports are filtered in the default squid.conf, but
-         * maybe someone wants them hardcoded... */
-        if (foundPort == 7 || foundPort == 9 || foundPort == 19) {
-            debugs(23, DBG_CRITICAL, MYNAME << "Deny access to port " << foundPort);
-            return false;
-        }
-#endif
-
         if (stringHasWhitespace(urlpath)) {
             debugs(23, 2, "URI has whitespace: {" << rawUrl << "}");
 
@@ -760,8 +748,6 @@ matchDomainName(const char *h, const char *d, MatchDomainNameFlags flags)
         return -1;
 
     dl = strlen(d);
-    if (dl == 0)
-        return 1;
 
     /*
      * Start at the ends of the two strings and work towards the
@@ -843,14 +829,13 @@ matchDomainName(const char *h, const char *d, MatchDomainNameFlags flags)
 /*
  * return true if we can serve requests for this method.
  */
-int
+bool
 urlCheckRequest(const HttpRequest * r)
 {
-    int rc = 0;
     /* protocol "independent" methods
      *
      * actually these methods are specific to HTTP:
-     * they are methods we recieve on our HTTP port,
+     * they are methods we receive on our HTTP port,
      * and if we had a FTP listener would not be relevant
      * there.
      *
@@ -859,7 +844,7 @@ urlCheckRequest(const HttpRequest * r)
      */
 
     if (r->method == Http::METHOD_CONNECT)
-        return 1;
+        return true;
 
     // we support OPTIONS and TRACE directed at us (with a 501 reply, for now)
     // we also support forwarding OPTIONS and TRACE, except for the *-URI ones
@@ -867,56 +852,48 @@ urlCheckRequest(const HttpRequest * r)
         return (r->header.getInt64(Http::HdrType::MAX_FORWARDS) == 0 || r->url.path() != AnyP::Uri::Asterisk());
 
     if (r->method == Http::METHOD_PURGE)
-        return 1;
+        return true;
 
     /* does method match the protocol? */
     switch (r->url.getScheme()) {
 
     case AnyP::PROTO_URN:
-
     case AnyP::PROTO_HTTP:
-
     case AnyP::PROTO_CACHE_OBJECT:
-        rc = 1;
-        break;
+        return true;
 
     case AnyP::PROTO_FTP:
-
-        if (r->method == Http::METHOD_PUT)
-            rc = 1;
-
-    case AnyP::PROTO_GOPHER:
+        if (r->method == Http::METHOD_PUT ||
+                r->method == Http::METHOD_GET ||
+                r->method == Http::METHOD_HEAD )
+            return true;
+        return false;
 
     case AnyP::PROTO_WAIS:
-
     case AnyP::PROTO_WHOIS:
-        if (r->method == Http::METHOD_GET)
-            rc = 1;
-        else if (r->method == Http::METHOD_HEAD)
-            rc = 1;
-
-        break;
+        if (r->method == Http::METHOD_GET ||
+                r->method == Http::METHOD_HEAD)
+            return true;
+        return false;
 
     case AnyP::PROTO_HTTPS:
-#if USE_OPENSSL
-        rc = 1;
-#elif USE_GNUTLS
-        rc = 1;
+#if USE_OPENSSL || USE_GNUTLS
+        return true;
 #else
         /*
-        * Squid can't originate an SSL connection, so it should
-        * never receive an "https:" URL.  It should always be
-        * CONNECT instead.
-        */
-        rc = 0;
+         * Squid can't originate an SSL connection, so it should
+         * never receive an "https:" URL.  It should always be
+         * CONNECT instead.
+         */
+        return false;
 #endif
-        break;
 
     default:
-        break;
+        return false;
     }
 
-    return rc;
+    /* notreached */
+    return false;
 }
 
 AnyP::Uri::Uri(AnyP::UriScheme const &aScheme) :
@@ -931,28 +908,29 @@ AnyP::Uri::Uri(AnyP::UriScheme const &aScheme) :
 char *
 AnyP::Uri::cleanup(const char *uri)
 {
-    int flags = 0;
     char *cleanedUri = nullptr;
     switch (Config.uri_whitespace) {
-    case URI_WHITESPACE_ALLOW:
-        flags |= RFC1738_ESCAPE_NOSPACE;
-    // fall through to next case
-    case URI_WHITESPACE_ENCODE:
-        flags |= RFC1738_ESCAPE_UNESCAPED;
+    case URI_WHITESPACE_ALLOW: {
+        const auto flags = RFC1738_ESCAPE_NOSPACE | RFC1738_ESCAPE_UNESCAPED;
         cleanedUri = xstrndup(rfc1738_do_escape(uri, flags), MAX_URL);
         break;
+    }
+
+    case URI_WHITESPACE_ENCODE:
+        cleanedUri = xstrndup(rfc1738_do_escape(uri, RFC1738_ESCAPE_UNESCAPED), MAX_URL);
+        break;
 
     case URI_WHITESPACE_CHOP: {
-        flags |= RFC1738_ESCAPE_UNESCAPED;
         const auto pos = strcspn(uri, w_space);
         char *choppedUri = nullptr;
         if (pos < strlen(uri))
             choppedUri = xstrndup(uri, pos + 1);
-        cleanedUri = xstrndup(rfc1738_do_escape(choppedUri ? choppedUri : uri, flags), MAX_URL);
+        cleanedUri = xstrndup(rfc1738_do_escape(choppedUri ? choppedUri : uri,
+                                                RFC1738_ESCAPE_UNESCAPED), MAX_URL);
         cleanedUri[pos] = '\0';
         xfree(choppedUri);
+        break;
     }
-    break;
 
     case URI_WHITESPACE_DENY:
     case URI_WHITESPACE_STRIP:
@@ -972,8 +950,8 @@ AnyP::Uri::cleanup(const char *uri)
         *q = '\0';
         cleanedUri = xstrndup(rfc1738_escape_unescaped(tmp_uri), MAX_URL);
         xfree(tmp_uri);
+        break;
     }
-    break;
     }
 
     assert(cleanedUri);
