@@ -17,7 +17,6 @@
 #include "fde.h"
 #include "ICP.h"
 #include "mgr/Registration.h"
-#include "SquidTime.h"
 #include "StatCounters.h"
 #include "StatHist.h"
 #include "Store.h"
@@ -64,7 +63,7 @@ static int nwritefds;
  * The variables 'incoming_udp_interval' and 'incoming_tcp_interval'
  * determine how many normal I/O events to process before checking
  * incoming sockets again.  Note we store the incoming_interval
- * multipled by a factor of (2^INCOMING_FACTOR) to have some
+ * multiplied by a factor of (2^INCOMING_FACTOR) to have some
  * pseudo-floating point precision.
  *
  * The variable 'udp_io_events' and 'tcp_io_events' counts how many normal
@@ -119,7 +118,7 @@ Comm::SetSelect(int fd, unsigned int type, PF * handler, void *client_data, time
     fde *F = &fd_table[fd];
     assert(fd >= 0);
     assert(F->flags.open || (!handler && !client_data && !timeout));
-    debugs(5, 5, HERE << "FD " << fd << ", type=" << type <<
+    debugs(5, 5, "FD " << fd << ", type=" << type <<
            ", handler=" << handler << ", client_data=" << client_data <<
            ", timeout=" << timeout);
 
@@ -311,7 +310,6 @@ comm_select_tcp_incoming(void)
     statCounter.comm_tcp_incoming.count(nevents);
 }
 
-#define DEBUG_FDBITS 0
 /* Select on all sockets; call handlers for those that are ready. */
 Comm::Flag
 Comm::DoSelect(int msec)
@@ -327,10 +325,6 @@ Comm::DoSelect(int msec)
     int pending;
     int calldns = 0, calludp = 0, calltcp = 0;
     int j;
-#if DEBUG_FDBITS
-
-    int i;
-#endif
     struct timeval poll_time;
     double timeout = current_dtime + (msec / 1000.0);
     fde *F;
@@ -390,20 +384,6 @@ Comm::DoSelect(int msec)
             }
         }
 
-#if DEBUG_FDBITS
-        for (i = 0; i < maxfd; ++i) {
-            /* Check each open socket for a handler. */
-
-            if (fd_table[i].read_handler) {
-                assert(FD_ISSET(i, readfds));
-            }
-
-            if (fd_table[i].write_handler) {
-                assert(FD_ISSET(i, writefds));
-            }
-        }
-
-#endif
         if (nreadfds + nwritefds == 0) {
             assert(shutting_down);
             return Comm::SHUTDOWN;
@@ -475,14 +455,6 @@ Comm::DoSelect(int msec)
             if (no_bits)
                 continue;
 
-#if DEBUG_FDBITS
-
-            debugs(5, 9, "FD " << fd << " bit set for reading");
-
-            assert(FD_ISSET(fd, readfds));
-
-#endif
-
             if (fdIsUdpListener(fd)) {
                 calludp = 1;
                 continue;
@@ -558,14 +530,6 @@ Comm::DoSelect(int msec)
             if (no_bits)
                 continue;
 
-#if DEBUG_FDBITS
-
-            debugs(5, 9, "FD " << fd << " bit set for writing");
-
-            assert(FD_ISSET(fd, writefds));
-
-#endif
-
             if (fdIsUdpListener(fd)) {
                 calludp = 1;
                 continue;
