@@ -10,13 +10,12 @@
 
 #include "squid.h"
 #include "comm/Loops.h"
-#include "Debug.h"
+#include "debug/Messages.h"
+#include "debug/Stream.h"
 #include "fatal.h"
 #include "fd.h"
 #include "fde.h"
 #include "globals.h"
-#include "profiler/Profiler.h"
-#include "SquidTime.h"
 
 // Solaris and possibly others lack MSG_NOSIGNAL optimization
 // TODO: move this into compat/? Use a dedicated compat file to avoid dragging
@@ -87,8 +86,8 @@ fd_close(int fd)
     assert(F->flags.open);
 
     if (F->type == FD_FILE) {
-        assert(F->read_handler == NULL);
-        assert(F->write_handler == NULL);
+        assert(F->read_handler == nullptr);
+        assert(F->write_handler == nullptr);
     }
 
     debugs(51, 3, "fd_close FD " << fd << " " << F->desc);
@@ -104,79 +103,50 @@ fd_close(int fd)
 int
 socket_read_method(int fd, char *buf, int len)
 {
-    int i;
-    PROF_start(recv);
-    i = recv(fd, (void *) buf, len, 0);
-    PROF_stop(recv);
-    return i;
+    return recv(fd, (void *) buf, len, 0);
 }
 
 int
 file_read_method(int fd, char *buf, int len)
 {
-    int i;
-    PROF_start(read);
-    i = _read(fd, buf, len);
-    PROF_stop(read);
-    return i;
+    return _read(fd, buf, len);
 }
 
 int
 socket_write_method(int fd, const char *buf, int len)
 {
-    int i;
-    PROF_start(send);
-    i = send(fd, (const void *) buf, len, 0);
-    PROF_stop(send);
-    return i;
+    return send(fd, (const void *) buf, len, 0);
 }
 
 int
 file_write_method(int fd, const char *buf, int len)
 {
-    int i;
-    PROF_start(write);
-    i = (_write(fd, buf, len));
-    PROF_stop(write);
-    return i;
+    return _write(fd, buf, len);
 }
 
 #else
 int
 default_read_method(int fd, char *buf, int len)
 {
-    int i;
-    PROF_start(read);
-    i = read(fd, buf, len);
-    PROF_stop(read);
-    return i;
+    return read(fd, buf, len);
 }
 
 int
 default_write_method(int fd, const char *buf, int len)
 {
-    int i;
-    PROF_start(write);
-    i = write(fd, buf, len);
-    PROF_stop(write);
-    return i;
+    return write(fd, buf, len);
 }
 
 int
 msghdr_read_method(int fd, char *buf, int)
 {
-    PROF_start(read);
-    const int i = recvmsg(fd, reinterpret_cast<msghdr*>(buf), MSG_DONTWAIT);
-    PROF_stop(read);
-    return i;
+    return recvmsg(fd, reinterpret_cast<msghdr*>(buf), MSG_DONTWAIT);
 }
 
 int
 msghdr_write_method(int fd, const char *buf, int len)
 {
-    PROF_start(write);
     const int i = sendmsg(fd, reinterpret_cast<const msghdr*>(buf), MSG_NOSIGNAL);
-    PROF_stop(write);
     return i > 0 ? len : i; // len is imprecise but the caller expects a match
 }
 
@@ -283,7 +253,7 @@ fdDumpOpen(void)
         if (i == fileno(debug_log))
             continue;
 
-        debugs(51, DBG_IMPORTANT, "Open FD "<< std::left<< std::setw(10) <<
+        debugs(51, Important(17), "Open FD "<< std::left<< std::setw(10) <<
                (F->bytes_read && F->bytes_written ? "READ/WRITE" :
                 F->bytes_read ? "READING" : F->bytes_written ? "WRITING" :
                 "UNSTARTED")  <<
