@@ -54,11 +54,11 @@ Fs::Ufs::UFSStrategy::unlinkFile(char const *path)
 }
 
 StoreIOState::Pointer
-Fs::Ufs::UFSStrategy::open(SwapDir * SD, StoreEntry * e, StoreIOState::STFNCB *,
+Fs::Ufs::UFSStrategy::open(SwapDir * const SD, StoreEntry * const e,
                            StoreIOState::STIOCB * aCallback, void *callback_data)
 {
     assert (((UFSSwapDir *)SD)->IO == this);
-    debugs(79, 3, HERE << "fileno "<< std::setfill('0') << std::hex
+    debugs(79, 3, "fileno "<< std::setfill('0') << std::hex
            << std::uppercase << std::setw(8) << e->swap_filen);
 
     /* to consider: make createstate a private UFSStrategy call */
@@ -70,12 +70,12 @@ Fs::Ufs::UFSStrategy::open(SwapDir * SD, StoreEntry * e, StoreIOState::STFNCB *,
 
     assert (state);
 
-    char *path = ((UFSSwapDir *)SD)->fullPath(e->swap_filen, NULL);
+    char *path = ((UFSSwapDir *)SD)->fullPath(e->swap_filen, nullptr);
 
     DiskFile::Pointer myFile = newFile (path);
 
-    if (myFile.getRaw() == NULL)
-        return NULL;
+    if (myFile.getRaw() == nullptr)
+        return nullptr;
 
     state->theFile = myFile;
 
@@ -84,19 +84,19 @@ Fs::Ufs::UFSStrategy::open(SwapDir * SD, StoreEntry * e, StoreIOState::STFNCB *,
     myFile->open (sio->mode, 0644, state);
 
     if (myFile->error())
-        return NULL;
+        return nullptr;
 
     return sio;
 }
 
 StoreIOState::Pointer
-Fs::Ufs::UFSStrategy::create(SwapDir * SD, StoreEntry * e, StoreIOState::STFNCB *,
+Fs::Ufs::UFSStrategy::create(SwapDir * const SD, StoreEntry * const e,
                              StoreIOState::STIOCB * aCallback, void *callback_data)
 {
     assert (((UFSSwapDir *)SD)->IO == this);
     /* Allocate a number */
     sfileno filn = ((UFSSwapDir *)SD)->mapBitAllocate();
-    debugs(79, 3, HERE << "fileno "<< std::setfill('0') <<
+    debugs(79, 3, "fileno "<< std::setfill('0') <<
            std::hex << std::uppercase << std::setw(8) << filn);
 
     /* Shouldn't we handle a 'bitmap full' error here? */
@@ -111,13 +111,13 @@ Fs::Ufs::UFSStrategy::create(SwapDir * SD, StoreEntry * e, StoreIOState::STFNCB
 
     assert (state);
 
-    char *path = ((UFSSwapDir *)SD)->fullPath(filn, NULL);
+    char *path = ((UFSSwapDir *)SD)->fullPath(filn, nullptr);
 
     DiskFile::Pointer myFile = newFile (path);
 
-    if (myFile.getRaw() == NULL) {
+    if (myFile.getRaw() == nullptr) {
         ((UFSSwapDir *)SD)->mapBitReset (filn);
-        return NULL;
+        return nullptr;
     }
 
     state->theFile = myFile;
@@ -128,7 +128,7 @@ Fs::Ufs::UFSStrategy::create(SwapDir * SD, StoreEntry * e, StoreIOState::STFNCB
 
     if (myFile->error()) {
         ((UFSSwapDir *)SD)->mapBitReset (filn);
-        return NULL;
+        return nullptr;
     }
 
     /* now insert into the replacement policy */
