@@ -48,7 +48,7 @@ public:
     Parser &operator =(const Parser &) = default;
     Parser(Parser &&) = default;
     Parser &operator =(Parser &&) = default;
-    virtual ~Parser() {}
+    ~Parser() override {}
 
     /// Set this parser back to a default state.
     /// Will DROP any reference to a buffer (does not free).
@@ -124,7 +124,9 @@ protected:
      * detect and skip the CRLF or (if tolerant) LF line terminator
      * consume from the tokenizer.
      *
-     * \throws exception on bad or InsufficientInput
+     * \throws exception on bad or InsuffientInput.
+     * \retval true only if line terminator found.
+     * \retval false incomplete or missing line terminator, need more data.
      */
     void skipLineTerminator(Tokenizer &) const;
 
