@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2022 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -14,11 +14,10 @@
 
 #if USE_ICMP
 
-#include "Debug.h"
+#include "debug/Stream.h"
 #include "Icmp6.h"
 #include "IcmpPinger.h"
-#include "leakcheck.h"
-#include "SquidTime.h"
+#include "time/gadgets.h"
 
 // Some system headers are only neeed internally here.
 // They should not be included via the header.
@@ -107,7 +106,7 @@ Icmp6::Open(void)
     }
 
     icmp_ident = getpid() & 0xffff;
-    debugs(42, DBG_IMPORTANT, "pinger: ICMPv6 socket opened");
+    debugs(42, DBG_IMPORTANT, "ICMPv6 socket opened");
 
     return icmp_sock;
 }
@@ -120,11 +119,13 @@ Icmp6::SendEcho(Ip::Address &to, int opcode, const char *payload, int len)
 {
     int x;
     LOCAL_ARRAY(char, pkt, MAX_PKT6_SZ);
-    struct icmp6_hdr *icmp = NULL;
-    icmpEchoData *echo = NULL;
-    struct addrinfo *S = NULL;
+    struct icmp6_hdr *icmp = nullptr;
+    icmpEchoData *echo = nullptr;
+    struct addrinfo *S = nullptr;
     size_t icmp6_pktsize = 0;
 
+    static_assert(sizeof(*icmp) + sizeof(*echo) <= sizeof(pkt), "our custom ICMPv6 Echo payload fits the packet buffer");
+
     memset(pkt, '\0', MAX_PKT6_SZ);
     icmp = (struct icmp6_hdr *)pkt;
 
@@ -147,7 +148,7 @@ Icmp6::SendEcho(Ip::Address &to, int opcode, const char *payload, int len)
     icmp6_pktsize = sizeof(struct icmp6_hdr);
 
     // Fill Icmp6 ECHO data content
-    echo = (icmpEchoData *) (pkt + sizeof(icmp6_hdr));
+    echo = reinterpret_cast<icmpEchoData *>(reinterpret_cast<char *>(pkt) + sizeof(*icmp));
     echo->opcode = (unsigned char) opcode;
     memcpy(&echo->tv, &current_time, sizeof(struct timeval));
 
@@ -169,7 +170,7 @@ Icmp6::SendEcho(Ip::Address &to, int opcode, const char *payload, int len)
 
     assert(icmp6_pktsize <= MAX_PKT6_SZ);
 
-    debugs(42, 5, HERE << "Send Icmp6 packet to " << to << ".");
+    debugs(42, 5, "Send Icmp6 packet to " << to << ".");
 
     x = sendto(icmp_sock,
                (const void *) pkt,
@@ -182,9 +183,9 @@ Icmp6::SendEcho(Ip::Address &to, int opcode, const char *payload, int len)
         int xerrno = errno;
         debugs(42, DBG_IMPORTANT, MYNAME << "ERROR: sending to ICMPv6 packet to " << to << ": " << xstrerr(xerrno));
     }
-    debugs(42,9, HERE << "x=" << x);
+    debugs(42,9, "x=" << x);
 
-    Log(to, 0, NULL, 0, 0);
+    Log(to, 0, nullptr, 0, 0);
     Ip::Address::FreeAddr(S);
 }
 
@@ -195,20 +196,20 @@ void
 Icmp6::Recv(void)
 {
     int n;
-    struct addrinfo *from = NULL;
+    struct addrinfo *from = nullptr;
 //    struct ip6_hdr *ip = NULL;
-    static char *pkt = NULL;
-    struct icmp6_hdr *icmp6header = NULL;
-    icmpEchoData *echo = NULL;
+    static char *pkt = nullptr;
+    struct icmp6_hdr *icmp6header = nullptr;
+    icmpEchoData *echo = nullptr;
     struct timeval now;
     static pingerReplyData preply;
 
     if (icmp_sock < 0) {
-        debugs(42, DBG_CRITICAL, HERE << "dropping ICMPv6 read. No socket!?");
+        debugs(42, DBG_CRITICAL, "dropping ICMPv6 read. No socket!?");
         return;
     }
 
-    if (pkt == NULL) {
+    if (pkt == nullptr) {
         pkt = (char *)xmalloc(MAX_PKT6_SZ);
     }
 
@@ -222,7 +223,7 @@ Icmp6::Recv(void)
                  &from->ai_addrlen);
 
     if (n <= 0) {
-        debugs(42, DBG_CRITICAL, HERE << "Error when calling recvfrom() on ICMPv6 socket.");
+        debugs(42, DBG_CRITICAL, "ERROR: when calling recvfrom() on ICMPv6 socket.");
         Ip::Address::FreeAddr(from);
         return;
     }
@@ -235,11 +236,11 @@ Icmp6::Recv(void)
 
 #else
 
-    gettimeofday(&now, NULL);
+    gettimeofday(&now, nullptr);
 
 #endif
 
-    debugs(42, 8, HERE << n << " bytes from " << preply.from);
+    debugs(42, 8, n << " bytes from " << preply.from);
 
 // XXX: The IPv6 Header (ip6_hdr) is not available directly
 //
@@ -260,7 +261,7 @@ Icmp6::Recv(void)
         ip = (struct ip6_hdr *) pkt;
         //  += sizeof(ip6_hdr);
 
-    debugs(42, DBG_CRITICAL, HERE << "ip6_nxt=" << ip->ip6_nxt <<
+    debugs(42, DBG_CRITICAL, "ip6_nxt=" << ip->ip6_nxt <<
             ", ip6_plen=" << ip->ip6_plen <<
             ", ip6_hlim=" << ip->ip6_hlim <<
             ", ip6_hops=" << ip->ip6_hops   <<
@@ -280,7 +281,7 @@ Icmp6::Recv(void)
             break;
 
         default:
-            debugs(42, 8, HERE << preply.from << " said: " << icmp6header->icmp6_type << "/" << (int)icmp6header->icmp6_code << " " <<
+            debugs(42, 8, preply.from << " said: " << icmp6header->icmp6_type << "/" << (int)icmp6header->icmp6_code << " " <<
                    IcmpPacketType(icmp6header->icmp6_type));
         }
         Ip::Address::FreeAddr(from);
@@ -288,7 +289,7 @@ Icmp6::Recv(void)
     }
 
     if (icmp6header->icmp6_id != icmp_ident) {
-        debugs(42, 8, HERE << "dropping Icmp6 read. IDENT check failed. ident=='" << icmp_ident << "'=='" << icmp6header->icmp6_id << "'");
+        debugs(42, 8, "dropping Icmp6 read. IDENT check failed. ident=='" << icmp_ident << "'=='" << icmp6header->icmp6_id << "'");
         Ip::Address::FreeAddr(from);
         return;
     }
