@@ -20,6 +20,9 @@
 #include "SquidIpc.h"
 #include "tools.h"
 
+#include <chrono>
+#include <thread>
+
 static const char *hello_string = "hi there\n";
 #ifndef HELLO_BUF_SZ
 #define HELLO_BUF_SZ 32
@@ -64,7 +67,7 @@ ipcCreate(int type, const char *prog, const char *const args[], const char *name
     pid_t pid;
     Ip::Address ChS;
     Ip::Address PaS;
-    struct addrinfo *AI = NULL;
+    struct addrinfo *AI = nullptr;
     int crfd = -1;
     int prfd = -1;
     int cwfd = -1;
@@ -85,7 +88,7 @@ ipcCreate(int type, const char *prog, const char *const args[], const char *name
         *wfd = -1;
 
     if (hIpc)
-        *hIpc = NULL;
+        *hIpc = nullptr;
 
 // NP: no wrapping around d and c usage since we *want* code expansion
 #define IPC_CHECK_FAIL(f,d,c) \
@@ -95,11 +98,11 @@ ipcCreate(int type, const char *prog, const char *const args[], const char *name
     } else void(0)
 
     if (type == IPC_TCP_SOCKET) {
-        crfd = cwfd = comm_open(SOCK_STREAM,
-                                0,
-                                local_addr,
-                                COMM_NOCLOEXEC,
-                                name);
+        crfd = cwfd = comm_open_listener(SOCK_STREAM,
+                                         0,
+                                         local_addr,
+                                         COMM_NOCLOEXEC,
+                                         name);
         prfd = pwfd = comm_open(SOCK_STREAM,
                                 0,          /* protocol */
                                 local_addr,
@@ -158,22 +161,22 @@ ipcCreate(int type, const char *prog, const char *const args[], const char *name
         errno = 0;
         if (setsockopt(fds[0], SOL_SOCKET, SO_SNDBUF, (void *) &buflen, sizeof(buflen)) == -1)  {
             xerrno = errno;
-            debugs(54, DBG_IMPORTANT, "setsockopt failed: " << xstrerr(xerrno));
+            debugs(54, DBG_IMPORTANT, "ERROR: setsockopt failed: " << xstrerr(xerrno));
             errno = 0;
         }
         if (setsockopt(fds[0], SOL_SOCKET, SO_RCVBUF, (void *) &buflen, sizeof(buflen)) == -1) {
             xerrno = errno;
-            debugs(54, DBG_IMPORTANT, "setsockopt failed: " << xstrerr(xerrno));
+            debugs(54, DBG_IMPORTANT, "ERROR: setsockopt failed: " << xstrerr(xerrno));
             errno = 0;
         }
         if (setsockopt(fds[1], SOL_SOCKET, SO_SNDBUF, (void *) &buflen, sizeof(buflen)) == -1) {
             xerrno = errno;
-            debugs(54, DBG_IMPORTANT, "setsockopt failed: " << xstrerr(xerrno));
+            debugs(54, DBG_IMPORTANT, "ERROR: setsockopt failed: " << xstrerr(xerrno));
             errno = 0;
         }
         if (setsockopt(fds[1], SOL_SOCKET, SO_RCVBUF, (void *) &buflen, sizeof(buflen)) == -1) {
             xerrno = errno;
-            debugs(54, DBG_IMPORTANT, "setsockopt failed: " << xstrerr(xerrno));
+            debugs(54, DBG_IMPORTANT, "ERROR: setsockopt failed: " << xstrerr(xerrno));
             errno = 0;
         }
         fd_open(prfd = pwfd = fds[0], FD_PIPE, "IPC UNIX STREAM Parent");
@@ -281,11 +284,11 @@ ipcCreate(int type, const char *prog, const char *const args[], const char *name
             hello_buf[x] = '\0';
 
         if (x < 0) {
-            debugs(54, DBG_CRITICAL, "ipcCreate: PARENT: hello read test failed");
+            debugs(54, DBG_CRITICAL, "ERROR: ipcCreate: PARENT: hello read test failed");
             debugs(54, DBG_CRITICAL, "--> read: " << xstrerr(xerrno));
             return ipcCloseAllFD(prfd, pwfd, crfd, cwfd);
         } else if (strcmp(hello_buf, hello_string)) {
-            debugs(54, DBG_CRITICAL, "ipcCreate: PARENT: hello read test failed");
+            debugs(54, DBG_CRITICAL, "ERROR: ipcCreate: PARENT: hello read test failed");
             debugs(54, DBG_CRITICAL, "--> read returned " << x);
             debugs(54, DBG_CRITICAL, "--> got '" << rfc1738_escape(hello_buf) << "'");
             return ipcCloseAllFD(prfd, pwfd, crfd, cwfd);
@@ -305,21 +308,15 @@ ipcCreate(int type, const char *prog, const char *const args[], const char *name
 
         fd_table[pwfd].flags.ipc = 1;
 
-        if (Config.sleep_after_fork) {
-            /* XXX emulation of usleep() */
-
-            struct timeval sl;
-            sl.tv_sec = Config.sleep_after_fork / 1000000;
-            sl.tv_usec = Config.sleep_after_fork % 1000000;
-            select(0, NULL, NULL, NULL, &sl);
-        }
+        if (Config.sleep_after_fork)
+            std::this_thread::sleep_for(std::chrono::microseconds(Config.sleep_after_fork));
 
         return pid;
     }
 
     /* child */
     TheProcessKind = pkHelper;
-    no_suid();          /* give up extra priviliges */
+    no_suid();          /* give up extra privileges */
 
     /* close shared socket with parent */
     close(prfd);
@@ -332,7 +329,7 @@ ipcCreate(int type, const char *prog, const char *const args[], const char *name
     if (type == IPC_TCP_SOCKET) {
         debugs(54, 3, "ipcCreate: calling accept on FD " << crfd);
 
-        if ((fd = accept(crfd, NULL, NULL)) < 0) {
+        if ((fd = accept(crfd, nullptr, nullptr)) < 0) {
             xerrno = errno;
             debugs(54, DBG_CRITICAL, "ipcCreate: FD " << crfd << " accept: " << xstrerr(xerrno));
             _exit(1);
@@ -352,14 +349,14 @@ ipcCreate(int type, const char *prog, const char *const args[], const char *name
         if (x < 0) {
             xerrno = errno;
             debugs(54, DBG_CRITICAL, "sendto FD " << cwfd << ": " << xstrerr(xerrno));
-            debugs(54, DBG_CRITICAL, "ipcCreate: CHILD: hello write test failed");
+            debugs(54, DBG_CRITICAL, "ERROR: ipcCreate: CHILD: hello write test failed");
             _exit(1);
         }
     } else {
         if (write(cwfd, hello_string, strlen(hello_string) + 1) < 0) {
             xerrno = errno;
             debugs(54, DBG_CRITICAL, "write FD " << cwfd << ": " << xstrerr(xerrno));
-            debugs(54, DBG_CRITICAL, "ipcCreate: CHILD: hello write test failed");
+            debugs(54, DBG_CRITICAL, "ERROR: ipcCreate: CHILD: hello write test failed");
             _exit(1);
         }
     }
