@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2022 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -60,7 +60,7 @@ Mgr::Response::clone() const
 bool
 Mgr::Response::hasAction() const
 {
-    return action != NULL;
+    return action != nullptr;
 }
 
 const Mgr::Action&
