@@ -20,7 +20,7 @@ namespace Ssl
 {
 
 /**
- * This class is used to hold the required informations to build
+ * This class is used to hold the required information to build
  * a request message for the certificate validator helper
  */
 class CertValidationRequest
@@ -32,7 +32,7 @@ public:
 };
 
 /**
- * This class is used to store informations found in certificate validation
+ * This class is used to store information found in certificate validation
  * response messages read from certificate validator helper
  */
 class CertValidationResponse: public RefCountable
@@ -41,7 +41,7 @@ public:
     typedef RefCount<CertValidationResponse> Pointer;
 
     /**
-     * This class used to hold error informations returned from
+     * This class used to hold error information returned from
      * cert validator helper.
      */
     class  RecvdError
@@ -57,6 +57,9 @@ public:
 
     typedef std::vector<RecvdError> RecvdErrors;
     explicit CertValidationResponse(const Security::SessionPointer &aSession) : ssl(aSession) {}
+
+    static uint64_t MemoryUsedByResponse(const CertValidationResponse::Pointer &);
+
     /// Search in errors list for the error item with id=errorId.
     /// If none found a new RecvdError item added with the given id;
     RecvdError &getError(int errorId);
@@ -67,7 +70,7 @@ public:
 
 /**
  * This class is responsible for composing or parsing messages destined to
- * or comming from a certificate validation helper.
+ * or coming from a certificate validation helper.
  * The messages format is:
 \verbatim
    response/request-code SP body-length SP [key=value ...] EOL
@@ -93,11 +96,11 @@ public:
     CertValidationMsg(MessageKind kind): CrtdMessage(kind) {}
 
     /// Build a request message for the cert validation helper
-    /// using informations provided by vcert object
+    /// using information provided by vcert object
     void composeRequest(CertValidationRequest const &vcert);
 
-    /// Parse a response message and fill the resp object with parsed informations
-    bool parseResponse(CertValidationResponse &resp, std::string &error);
+    /// Parse a response message and fill the resp object with parsed information
+    bool parseResponse(CertValidationResponse &resp);
 
     /// Search a CertItems list for the certificate with ID "name"
     X509 *getCertByName(std::vector<CertItem> const &, std::string const & name);
@@ -120,6 +123,9 @@ public:
     static const std::string param_proto_version;
     /// Parameter name for SSL cipher
     static const std::string param_cipher;
+
+private:
+    void tryParsingResponse(CertValidationResponse &);
 };
 
 }//namespace Ssl
