@@ -22,7 +22,7 @@ StoreIoStats store_io_stats;
  * to select different polices depending on object size or type.
  */
 StoreIOState::Pointer
-storeCreate(StoreEntry * e, StoreIOState::STFNCB * file_callback, StoreIOState::STIOCB * close_callback, void *callback_data)
+storeCreate(StoreEntry * e, StoreIOState::STIOCB * close_callback, void *callback_data)
 {
     assert (e);
 
@@ -32,21 +32,18 @@ storeCreate(StoreEntry * e, StoreIOState::STFNCB * file_callback, StoreIOState::
      * Pick the swapdir
      * We assume that the header has been packed by now ..
      */
-    const sdirno dirn = storeDirSelectSwapDir(e);
+    const auto sd = Store::Disks::SelectSwapDir(e);
 
-    if (dirn == -1) {
+    if (!sd) {
         debugs(20, 2, "storeCreate: no swapdirs for " << *e);
         ++store_io_stats.create.select_fail;
-        return NULL;
+        return nullptr;
     }
 
-    debugs(20, 2, "storeCreate: Selected dir " << dirn << " for " << *e);
-    SwapDir *SD = dynamic_cast<SwapDir *>(INDEXSD(dirn));
-
     /* Now that we have a fs to use, call its storeCreate function */
-    StoreIOState::Pointer sio = SD->createStoreIO(*e, file_callback, close_callback, callback_data);
+    StoreIOState::Pointer sio = sd->createStoreIO(*e, close_callback, callback_data);
 
-    if (sio == NULL)
+    if (sio == nullptr)
         ++store_io_stats.create.create_fail;
     else
         ++store_io_stats.create.success;
@@ -58,23 +55,23 @@ storeCreate(StoreEntry * e, StoreIOState::STFNCB * file_callback, StoreIOState::
  * storeOpen() is purely for reading ..
  */
 StoreIOState::Pointer
-storeOpen(StoreEntry * e, StoreIOState::STFNCB * file_callback, StoreIOState::STIOCB * callback,
+storeOpen(StoreEntry * e, StoreIOState::STIOCB * callback,
           void *callback_data)
 {
-    return e->disk().openStoreIO(*e, file_callback, callback, callback_data);
+    return e->disk().openStoreIO(*e, callback, callback_data);
 }
 
 void
 storeClose(StoreIOState::Pointer sio, int how)
 {
     if (sio->flags.closing) {
-        debugs(20,3,HERE << "storeClose: flags.closing already set, bailing");
+        debugs(20,3, "storeClose: flags.closing already set, bailing");
         return;
     }
 
     sio->flags.closing = true;
 
-    debugs(20,3,HERE << "storeClose: calling sio->close(" << how << ")");
+    debugs(20,3, "storeClose: calling sio->close(" << how << ")");
     sio->close(how);
 }
 
