@@ -22,7 +22,7 @@ class testConfigParser : public CPPUNIT_NS::TestFixture
     CPPUNIT_TEST_SUITE_END();
 
 public:
-    void setUp();
+    void setUp() override;
 
 protected:
     bool doParseQuotedTest(const char *, const char *);
