@@ -22,7 +22,6 @@
 #include "MemBuf.h"
 #include "mime_header.h"
 #include "RequestFlags.h"
-#include "SquidTime.h"
 #include "Store.h"
 #include "StoreClient.h"
 #include "tools.h"
@@ -37,11 +36,10 @@ class UrnState : public StoreClient
 public:
     explicit UrnState(const AccessLogEntry::Pointer &anAle): ale(anAle) {}
 
-    void created (StoreEntry *newEntry);
     void start (HttpRequest *, StoreEntry *);
     void setUriResFromRequest(HttpRequest *);
 
-    virtual ~UrnState();
+    ~UrnState() override;
 
     StoreEntry *entry = nullptr;
     store_client *sc = nullptr;
@@ -55,8 +53,8 @@ public:
 
 private:
     /* StoreClient API */
-    virtual LogTags *loggingTags() { return ale ? &ale->cache.code : nullptr; }
-    virtual void fillChecklist(ACLFilledChecklist &) const;
+    LogTags *loggingTags() const override { return ale ? &ale->cache.code : nullptr; }
+    void fillChecklist(ACLFilledChecklist &) const override;
 
     char *urlres = nullptr;
 };
@@ -97,14 +95,14 @@ static url_entry *
 urnFindMinRtt(url_entry * urls, const HttpRequestMethod &, int *rtt_ret)
 {
     int min_rtt = 0;
-    url_entry *u = NULL;
-    url_entry *min_u = NULL;
+    url_entry *u = nullptr;
+    url_entry *min_u = nullptr;
     int i;
     int urlcnt = 0;
     debugs(52, 3, "urnFindMinRtt");
-    assert(urls != NULL);
+    assert(urls != nullptr);
 
-    for (i = 0; NULL != urls[i].url; ++i)
+    for (i = 0; nullptr != urls[i].url; ++i)
         ++urlcnt;
 
     debugs(53, 3, "urnFindMinRtt: Counted " << i << " URLs");
@@ -172,32 +170,22 @@ UrnState::start(HttpRequest * r, StoreEntry * e)
     entry->lock("UrnState::start");
     setUriResFromRequest(r);
 
-    if (urlres_r == NULL)
+    if (urlres_r == nullptr)
         return;
 
-    StoreEntry::getPublic (this, urlres, Http::METHOD_GET);
-}
+    auto urlEntry = storeGetPublic(urlres, Http::METHOD_GET);
 
-void
-UrnState::fillChecklist(ACLFilledChecklist &checklist) const
-{
-    checklist.setRequest(request.getRaw());
-    checklist.al = ale;
-}
-
-void
-UrnState::created(StoreEntry *e)
-{
-    if (!e || (e->hittingRequiresCollapsing() && !startCollapsingOn(*e, false))) {
+    if (!urlEntry || (urlEntry->hittingRequiresCollapsing() && !startCollapsingOn(*urlEntry, false))) {
         urlres_e = storeCreateEntry(urlres, urlres, RequestFlags(), Http::METHOD_GET);
         sc = storeClientListAdd(urlres_e, this);
         FwdState::Start(Comm::ConnectionPointer(), urlres_e, urlres_r.getRaw(), ale);
-        // TODO: StoreClients must either store/lock or abandon found entries.
-        //if (e)
-        //    e->abandon();
+        if (urlEntry) {
+            urlEntry->abandon(__FUNCTION__);
+            urlEntry = nullptr;
+        }
     } else {
-        urlres_e = e;
-        urlres_e->lock("UrnState::created");
+        urlres_e = urlEntry;
+        urlres_e->lock("UrnState::start");
         sc = storeClientListAdd(urlres_e, this);
     }
 
@@ -212,6 +200,13 @@ UrnState::created(StoreEntry *e)
                     this);
 }
 
+void
+UrnState::fillChecklist(ACLFilledChecklist &checklist) const
+{
+    checklist.setRequest(request.getRaw());
+    checklist.al = ale;
+}
+
 void
 urnStart(HttpRequest *r, StoreEntry *e, const AccessLogEntryPointer &ale)
 {
@@ -242,7 +237,7 @@ urnHandleReply(void *data, StoreIOBuffer result)
     UrnState *urnState = static_cast<UrnState *>(data);
     StoreEntry *e = urnState->entry;
     StoreEntry *urlres_e = urnState->urlres_e;
-    char *s = NULL;
+    char *s = nullptr;
     size_t k;
     HttpReply *rep;
     url_entry *urls;
@@ -335,7 +330,7 @@ urnHandleReply(void *data, StoreIOBuffer result)
 
     debugs(53, 3, "urnFindMinRtt: Counted " << i << " URLs");
 
-    min_u = urnFindMinRtt(urls, urnState->request->method, NULL);
+    min_u = urnFindMinRtt(urls, urnState->request->method, nullptr);
     qsort(urls, urlcnt, sizeof(*urls), url_entry_sort);
     e->buffer();
     SBuf body;
@@ -366,9 +361,9 @@ urnHandleReply(void *data, StoreIOBuffer result)
         "<ADDRESS>\n"
         "Generated by %s@%s\n"
         "</ADDRESS>\n",
-        APP_FULLNAME, getMyHostname());
+        visible_appname_string, getMyHostname());
     rep = new HttpReply;
-    rep->setHeaders(Http::scFound, NULL, "text/html", mb->length(), 0, squid_curtime);
+    rep->setHeaders(Http::scFound, nullptr, "text/html", mb->length(), 0, squid_curtime);
 
     if (min_u) {
         rep->header.putStr(Http::HdrType::LOCATION, min_u->url);
@@ -400,7 +395,7 @@ urnParseReply(const char *inbuf, const HttpRequestMethod& m)
     debugs(52, 3, "urnParseReply");
     list = (url_entry *)xcalloc(n + 1, sizeof(*list));
 
-    for (token = strtok(buf, crlf); token; token = strtok(NULL, crlf)) {
+    for (token = strtok(buf, crlf); token; token = strtok(nullptr, crlf)) {
         debugs(52, 3, "urnParseReply: got '" << token << "'");
 
         if (i == n) {
