@@ -20,6 +20,7 @@
 #include "StatCounters.h"
 #include "Store.h"
 #include "tools.h"
+#include "whois.h"
 
 #include <cerrno>
 
@@ -71,7 +72,7 @@ whoisStart(FwdState * fwd)
 
     AsyncCall::Pointer writeCall = commCbCall(5,5, "whoisWriteComplete",
                                    CommIoCbPtrFun(whoisWriteComplete, p));
-    Comm::Write(fwd->serverConnection(), buf, strlen(buf), writeCall, NULL);
+    Comm::Write(fwd->serverConnection(), buf, strlen(buf), writeCall, nullptr);
     AsyncCall::Pointer readCall = commCbCall(5,4, "whoisReadReply",
                                   CommIoCbPtrFun(whoisReadReply, p));
     comm_read(fwd->serverConnection(), p->buf, BUFSIZ, readCall);
@@ -86,7 +87,7 @@ static void
 whoisTimeout(const CommTimeoutCbParams &io)
 {
     WhoisState *p = static_cast<WhoisState *>(io.data);
-    debugs(75, 3, HERE << io.conn << ", URL " << p->entry->url());
+    debugs(75, 3, io.conn << ", URL " << p->entry->url());
     io.conn->close();
 }
 
@@ -115,7 +116,7 @@ WhoisState::readReply(const Comm::ConnectionPointer &conn, char *aBuffer, size_t
         return;
 
     aBuffer[aBufferLength] = '\0';
-    debugs(75, 3, HERE << conn << " read " << aBufferLength << " bytes");
+    debugs(75, 3, conn << " read " << aBufferLength << " bytes");
     debugs(75, 5, "{" << aBuffer << "}");
 
     // TODO: Honor delay pools.
@@ -171,6 +172,8 @@ WhoisState::readReply(const Comm::ConnectionPointer &conn, char *aBuffer, size_t
 
     if (dataWritten) // treat zero-length responses as incomplete
         fwd->markStoredReplyAsWhole("whois received/stored the entire response");
+    else
+        fwd->fail(new ErrorState(ERR_ZERO_SIZE_OBJECT, Http::scBadGateway, fwd->request, fwd->al));
 
     fwd->complete();
     debugs(75, 3, "whoisReadReply: Done: " << entry->url());
